@@ -11,6 +11,7 @@ from apm import *
 def f(a: int, b: float, c: str, d: str) -> str:
     pass
 
+
 class TypingUtil(unittest.TestCase):
 
     def test_get_arg_types(self):
@@ -23,3 +24,10 @@ class TypingUtil(unittest.TestCase):
     def test_get_return_type(self):
         self.assertEqual(str, util.get_return_type(f))
 
+    def test_invoke(self):
+        args = {
+            "b": 3,
+            "c": 4,
+        }
+        result = util.invoke(lambda a, b: (a, b), args)
+        self.assertEqual((None, 3), result)
